#ifndef RCGH
#define RCGH

/******************************************************************************
               RCG Constants
*******************************************************************************/
#if defined (_WIN32)
   #if !defined(WIN32)
     #define WIN32
   #endif
#endif

#define RCG_DATA_VER       101

#define RCG_MAX_WIDTH      300
#define RCG_MAX_TAB_STOPS  20
#define CELL_MARGIN        60      // cell margin in twips


#define RCG_HDR                1
#define RCG_FHDR               2
#define RCG_LHDR               3
#define RCG_RHDR               4
#define RCG_FTR                5
#define RCG_FFTR               6
#define RCG_LFTR               7
#define RCG_RFTR               8

#define RCG_ULINE              0x1   
#define RCG_BOLD               0x2   
#define RCG_ITALIC             0x4   
#define RCG_STRIKE             0x8   
#define RCG_SUPSCR             0x10  
#define RCG_SUBSCR             0x20  
#define RCG_HIDDEN             0x40  
#define RCG_PICT               0x80  
#define RCG_ULINED             0x100  
#define RCG_PROTECT            0x200
#define RCG_FNOTE              0x400
#define RCG_FNOTETEXT          0x800
#define RCG_FNORCGEST          0x1000
#define RCG_CHAR_BOX           0x2000
#define RCG_HLINK              0x4000
#define RCG_CAPS               0x10000
#define RCG_SCAPS              0x20000

#define RCG_FNOTEALL           (FNOTE|FNOTETEXT|FNORCGEST)

#define RCG_CENTER             0x1
#define RCG_RIGHT              0x2
#define RCG_DOUBLE_SPACE       0x4
#define RCG_BULLET             0x8
#define RCG_BOX_TOP            0x10
#define RCG_BOX_BOT            0x20
#define RCG_BOX_LEFT           0x40
#define RCG_BOX_RIGHT          0x80
#define RCG_BOX_DOUBLE         0x100
#define RCG_BOX_THICK          0x200
#define RCG_BOX_ATTRIB         0x3F0
#define RCG_LEFT               0x400
#define RCG_JUSTIFY            0x800
#define RCG_PAGE_HDR           0x1000
#define RCG_PAGE_FTR           0x2000
#define RCG_PAGE_HDR_FTR       0x3000
#define RCG_PARA_KEEP          0x4000
#define RCG_PARA_KEEP_NEXT     0x8000
#define RCG_PARA_WIDOW         0x10000

#define RCG_PARA_BOX           0xF0

#define RCG_VALIGN_TOP         0
#define RCG_VALIGN_CTR         1
#define RCG_VALIGN_BOT         2

#define RCG_MRG_COL_FIRST   0x1
#define RCG_MRG_COL         0x2
#define RCG_MRG_ROW_FIRST   0x4
#define RCG_MRG_ROW         0x8

#define PAGE_CHAR           12       // new page character
#define NBSPACE_CHAR        14       // non-breaking space character
#define LINE_CHAR           15       // line break character
#define PARA_CHAR           21       // new paragraph character
#define COL_CHAR            22       // new column character
#define NBDASH_CHAR         23       // non-breaking dash character

#define RCG_BREAK_SECT      0        // section break
#define RCG_BREAK_COL       1        // column break
#define RCG_BREAK_PAGE      2        // page break

#define TAB_LEFT            0
#define TAB_RIGHT           1
#define TAB_CENTER          2
#define TAB_DECIMAL         3

#define TAB_NONE            0         // only one value applicable
#define TAB_DOT             1
#define TAB_HYPH            2
#define TAB_ULINE           4

#define ALIGN_BOT            0        // align picture bottom to base line
#define ALIGN_MIDDLE         1        // center picture vertically to baseline
#define ALIGN_TOP            2        // align picture top to base line

#define PFRAME_NONE          0        // not a picture frame
#define PFRAME_LEFT          1        // left alignment picture frame
#define PFRAME_RIGHT         2        // right alignment picture frame
#define PFRAME_FLOAT         3        // not left or right aligned frame

#define DOB_TEXT_BOX         1        // text box
#define DOB_RECT             2        // rectangle
#define DOB_LINE             3        // line

#define DOB_LINE_NONE        0        // no line or border
#define DOB_LINE_SOLID       1        // solid line
#define DOB_LINE_DOTTED      2        // dotted line

#define SSTYPE_CHAR          1          // character type style sheet
#define SSTYPE_PARA          2          // paragraph type style sheet

#define BASE_PAGE      0              // object y position relative to the top of the page
#define BASE_MARG      1              // object y position relative to the top margin
#define BASE_PARA      2              // object y position relative to the anchor paragraph

#define RFLAG_RETURN_MSG_ID    0x1    // saves the msg ids to return to the user program.
#define RFLAG_FIRST_MSG_ONLY   0x2    // display only the first message

#define BLT_ROUND             1             // 20101228: incremented the values so that 0 is not used for BLT_ROUND
#define BLT_DIAMOND           2
#define BLT_SQUARE            3
#define BLT_HOLLOW_SQUARE     4
#define BLT_4_DIAMONDS        5
#define BLT_ARROW             6
#define BLT_CHECK             7

#define BLTFLAG_HIDDEN        0x1

#define NBR_DEC               0     // decimal numbering
#define NBR_UPR_ALPHA         1
#define NBR_LWR_ALPHA         2
#define NBR_UPR_ROMAN         3
#define NBR_LWR_ROMAN         4

#define PID_LINE              0
#define PID_PARA              1
#define PID_BULLET            2

#define RCG_FILE              1
#define RCG_BUF               2

/******************************************************************************
    Message ids
*******************************************************************************/
#define RMSG_NO_ERROR            0
#define RMSG_BAD_BMP_FILE        1
#define RMSG_CREATE_NEW_FILE     2
#define RMSG_ERR_DIB_CREATE      3
#define RMSG_ERR_FILE_LENGTH     4
#define RMSG_ERR_FILE_OPEN       5
#define RMSG_ERR_FILE_READ       6
#define RMSG_ERR_FILE_SEEK       7
#define RMSG_ERR_FILE_WRITE      8
#define RMSG_ERR_FONT_CREATE     9
#define RMSG_ERR_FONT_SELECT     10
#define RMSG_ERR_INIT_BMP        11
#define RMSG_ERR_MEM_LOCK        12
#define RMSG_ERR_META_ACCESS     13
#define RMSG_ERR_META_BAD_FILE   14
#define RMSG_ERR_META_COPY       15
#define RMSG_ERR_META_CREATE     16
#define RMSG_ERR_META_READ       17
#define RMSG_ERR_META_RECREATE   18
#define RMSG_ERR_PICT_FILE_FMT   19
#define RMSG_ERR_PICT_FILE_OPEN  20
#define RMSG_ERR_PICT_FILE_READ  21
#define RMSG_LINE_TOO_LONG       22
#define RMSG_OUT_OF_MEM          23
#define RMSG_READ_ABORTED        24
#define RMSG_REPLACE_STRING      25
#define RMSG_SAVE_INCOMPL        26
#define RMSG_UNEXPECTED_EOF      27
#define RMSG_ERR_FILE_ACCESS     28
#define RMSG_ERR_ENH_META_HDR    29
#define RMSG_GET_ENH_META        30
#define RMSG_IN_INIT_SECT        31
#define RMSG_NOT_IN_INIT_SECT    32
#define RMSG_IN_TEXT             33
#define RMSG_NOT_IN_TEXT         34
#define RMSG_IN_SSITEM           35
#define RMSG_NOT_IN_SSITEM       36
#define RMSG_IN_SS               37
#define RMSG_NOT_IN_SS           38
#define RMSG_IN_TABLE            39
#define RMSG_NOT_IN_TABLE        40
#define RMSG_IN_FRAME            41
#define RMSG_NOT_IN_FRAME        42
#define RMSG_IN_TEXT_BOX         43
#define RMSG_NOT_IN_TEXT_BOX     44
#define RMSG_IN_HDR_FTR          45
#define RMSG_NOT_IN_HDR_FTR      46

#define RMSG_BAD_SEQ             47
#define RMSG_TEMP                48

#define RMSG_IN_CELL_TEXT        49
#define RMSG_NOT_IN_CELL_TEXT    50

#define RMSG_CELLX_MISSING       51
#define RMSG_NO_MORE_CELLX       52
#define RMSG_NO_CELLS            53
#define RMSG_LESS_CELLS          54
#define RMSG_CLIPBOARD_BUSY      55
#define RMSG_CLIPBOARD_NO_DATA   56
#define RMSG_CLIPBOARD_NO_FMT    57
#define RMSG_IN_SCRIPT           58
#define RMSG_NOT_IN_SCRIPT       59
#define RMSG_TABLE_MISMATCH      60


/******************************************************************************
    WIN32 specific defines
*******************************************************************************/
#if defined (WIN32)
   #define RCG_HUGE
   #define _export
#else
   #define RCG_HUGE huge 
#endif


/****************************************************************************
   Instructions for packing the following structure
*****************************************************************************/
#ifndef RC_INVOKED
   #pragma pack(1)
#endif

/****************************************************************************
   Instructions to resume the default structure packing.
*****************************************************************************/
#ifndef RC_INVOKED
   #pragma pack()
#endif


/******************************************************************************
                     Editor Function Prototype
   When calling RCG from a C program, leave the RCG_CPLUSPLUS symbol undefined.

   When calling RCG from a C++ program, define the RCG_CPLUSPLUS as following:

   #define RCG_CPLUSPLUS extern "C"
   #include "ter.h"
*******************************************************************************/
#ifndef RCG_CPLUSPLUS
   #if defined(__cplusplus) 
      #define RCG_CPLUSPLUS extern "C"
   #else
      #define RCG_CPLUSPLUS
   #endif
#endif

RCG_CPLUSPLUS DWORD   WINAPI _export RcgNewDoc(void);
RCG_CPLUSPLUS int     WINAPI _export RcgGetLastMessage(LPBYTE,LPBYTE);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgResetLastMessage(void);
RCG_CPLUSPLUS HANDLE  WINAPI _export RcgStrToHandle(BYTE RCG_HUGE *,long);
RCG_CPLUSPLUS HANDLE  WINAPI _export RcgStrToHandleInChunks(BYTE RCG_HUGE *,long,HANDLE,long,long);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgHandleToStr(BYTE RCG_HUGE *,long,HANDLE);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgHandleToStrInChunks(BYTE RCG_HUGE *,long,HANDLE,long,long);
RCG_CPLUSPLUS int     WINAPI _export RcgMakeMbcs(LPBYTE,LPBYTE,LPBYTE,int);  
RCG_CPLUSPLUS BOOL    WINAPI _export RcgSaveFile(DWORD,LPBYTE);       
RCG_CPLUSPLUS HGLOBAL WINAPI _export RcgGetData(DWORD,LPLONG);       
RCG_CPLUSPLUS BOOL    WINAPI _export RcgEndDoc(DWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgTextFont(DWORD,LPBYTE,int,UINT,BOOL);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgInsertText(DWORD,LPBYTE);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgBeginSectText(DWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgTextColor(DWORD,COLORREF,BOOL);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgResetTextProp(DWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgResetParaProp(DWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgCharStyleId(DWORD, int);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgParaStyleId(DWORD, int);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgParaFlags(DWORD,DWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgParaIndent(DWORD,int,int,int);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgParaSpace(DWORD,int,int,int);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgParaShadeColor(DWORD,int,COLORREF);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgParaBullet(DWORD,BOOL,int,int,int,LPBYTE,LPBYTE,UINT);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgParaTabStop(DWORD,int,int,UINT);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgInitSect(DWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgPaper(DWORD,int,int,BOOL);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgMargin(DWORD,int,int,int,int,int,int);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgSectInfo(DWORD,int,int,BOOL,int);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgBeginTableRow(DWORD,int,int,int,BOOL,int);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgNextCellInfo(DWORD,int,int,int,COLORREF,int,int,int,int,UINT);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgBeginCellText(DWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgEndCellText(DWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgEndTableRow(DWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgBeginHdrFtr(DWORD,int);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgEndHdrFtr(DWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgInsertPictFile(DWORD,LPBYTE,int,int,BOOL);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgBeginStyleSheet(DWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgBeginStyleItem(DWORD,BOOL,int,LPBYTE);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgEndStyleItem(DWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgEndStyleSheet(DWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgBeginFrame(DWORD,BOOL,int,int,int,int);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgEndFrame(DWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgBeginTextBox(DWORD,BOOL,int,int,int,int,int,COLORREF,COLORREF,int,BOOL);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgEndTextBox(DWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgDrawRect(DWORD,BOOL,int,int,int,int,int,COLORREF,COLORREF,int,BOOL);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgDrawLine(DWORD,BOOL,int,int,int,int,int,COLORREF,int);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgInsertBreak(DWORD,int);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgBeginGroup(DWORD,LPBYTE,BOOL);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgEndGroup(DWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgInsertControl(DWORD,LPBYTE,BOOL,long);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgInsertPageField(DWORD,BOOL);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgPastePicture(DWORD,UINT,HGLOBAL,int,int);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgInsertMergeField(DWORD,LPBYTE,LPBYTE);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgInsertRaw(DWORD,LPBYTE);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgInsertFootnote(DWORD,LPBYTE,LPBYTE);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgInsertUText(DWORD,LPWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgInsertBookmark(DWORD,LPBYTE,BOOL);
RCG_CPLUSPLUS DWORD   WINAPI _export RcgSetFlags(DWORD,BOOL,DWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgNextCellInfo2(DWORD,int,int,int,COLORREF,int,int,int,int,COLORREF,UINT);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgInsertTocField(DWORD,int,int);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgSetLicenseKey(LPBYTE);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgBeginTableRow2(DWORD,int, int, int, BOOL, int, int, int, int);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgTextFont2(DWORD,LPBYTE, int, UINT, int, BOOL);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgBeginTextBox2(DWORD,BOOL,int,int,int,int,int,COLORREF,COLORREF,int,BOOL,int);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgNextCellInfo3(DWORD,int,int,int,COLORREF,int,int,int,int,COLORREF,UINT,int);


// Undocumented functions - do not use them without consultation with Sub Systems, Inc.
RCG_CPLUSPLUS BOOL    WINAPI _export RcgBeginScriptStyle(DWORD,BOOL);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgEndScriptStyle(DWORD);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgTextColor2(DWORD,COLORREF , BOOL , BOOL);
RCG_CPLUSPLUS BOOL    WINAPI _export RcgTextFont3(DWORD,LPBYTE, int, UINT, int, BOOL, BOOL);


#endif
